@@ -21,7 +21,15 @@ ukppd_avail_items <- function() {
   query <- build_sparql_file_query(
     "ppi", "transaction", "0A73B494-6838-4604-961B-0453DF4CC0BB", "current")
   proc <- process_request(query)
-  gsub(".*/ppi/(.+)", "\\1", proc$type[-1])
+  all_items <- gsub(".*/ppi/(.+)", "\\1", proc$type[-1])
+  already_included <- c("transactionDate", "pricePaid", "transactionCategory")
+  setdiff(all_items, already_included)
+  # lrppi_label <- c("recordStatus", "propertyType", "estateType", "transactionCategory")
+  # if (label) {
+  #   skos_label <- out %in% lrppi_label
+  #   out[skos_label] <- paste0(out[skos_label], "/skos:prefLabel")
+  # }
+  # out
 }
 
 #'@rdname ukppd_avail_items
@@ -30,11 +38,14 @@ ukppd_avail_optional_items <- function() {
   query <- build_sparql_file_query(
     "ppi", "address", "e738e64c33d83e5492f9a1bb0e3e4c24ed4ce684")
   proc <- process_request(query)
-  gsub(".*/common/(.+)", "\\1", proc$type[-1])
+  all_items <- gsub(".*/common/(.+)", "\\1", proc$type[-1])
+  already_included <- c("postcode")
+  setdiff(all_items, already_included)
 }
 
 #' @rdname ukppd_avail_items
 #' @export
 ukppd_avail_postcodes <- function() {
- ons_pc()
+  pc$NUTS3 <- gsub("[0-9]", "", pc$NUTS3)
+  pc[!pc$NUTS3 %in% c("UKM", "UKN"), ]$CODE
 }
