@@ -15,7 +15,11 @@
 #' ukhp_def()
 #' }
 uklr_def <- function() {
-  def <- read.csv("http://landregistry.data.gov.uk/def/common.csv?_pageSize=100")
+  def <- try_read_csv("http://landregistry.data.gov.uk/def/common.csv?_pageSize=100")
+  if (!tibble::is_tibble(def)) {
+    message(def)
+    return(invisible(NULL))
+  }
   def$uri <- gsub(".*ukhpi/(.+)", "\\1", def$uri)
   as_tibble(def)
 }
@@ -23,7 +27,11 @@ uklr_def <- function() {
 #' @rdname uklr_def
 #' @export
 ukhp_def <- function() {
-  def <- read.csv("http://landregistry.data.gov.uk/def/ukhpi.csv?_pageSize=100")
+  def <- try_read_csv("http://landregistry.data.gov.uk/def/ukhpi.csv?_pageSize=100")
+  if (!tibble::is_tibble(def)) {
+    message(def)
+    return(invisible(NULL))
+  }
   def$uri <- gsub(".*ukhpi/(.+)", "\\1", def$uri)
   nms <- names(def)
   nms_ <- gsub("\\.\\.\\.", "_", nms)
@@ -34,7 +42,11 @@ ukhp_def <- function() {
 #' @rdname uklr_def
 #' @export
 ukppd_def <- function() {
-  def <- read.csv("http://landregistry.data.gov.uk/def/ppi.csv?_pageSize=100")
+  def <- try_read_csv("http://landregistry.data.gov.uk/def/ppi.csv?_pageSize=100")
+  if (!tibble::is_tibble(def)) {
+    message(def)
+    return(invisible(NULL))
+  }
   def$uri <- gsub(".*ppi/(.+)", "\\1", def$uri)
   nms <- names(def)
   nms_ <- gsub("\\.\\.\\.", "_", nms)
@@ -44,12 +56,25 @@ ukppd_def <- function() {
 
 
 #' @rdname uklr_def
+#' @importFrom tibble is_tibble
 #' @export
 uktrans_def <- function() {
-  def <- read.csv("http://landregistry.data.gov.uk/def/trans.csv?_pageSize=100")
+  def <- try_read_csv("http://landregistry.data.gov.uk/def/trans.csv?_pageSize=100")
+  if (!tibble::is_tibble(def)) {
+    message(def)
+    return(invisible(NULL))
+  }
   def$uri <- gsub(".*trans/(.+)", "\\1", def$uri)
   nms <- names(def)
   nms_ <- gsub("\\.\\.\\.", "_", nms)
   names(def) <- gsub("\\.", "", nms_)
   as_tibble(def)
 }
+
+try_read_csv <- function(x, ...) {
+  tryCatch(
+    read.csv(x, ...),
+    error = function(e) conditionMessage(e),
+    warning = function(w) conditionMessage(w)
+  )
+}
